==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/BuildTriggerCauseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BuildTriggerCauseBuilder extends io.fabric8.openshift.api.model.BuildTriggerCauseFluentImpl<io.fabric8.openshift.api.model.BuildTriggerCauseBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.BuildTriggerCause,io.fabric8.openshift.api.model.BuildTriggerCauseBuilder>{
  public BuildTriggerCauseBuilder() {
    this(false);
  }
  public BuildTriggerCauseBuilder(java.lang.Boolean validationEnabled) {
    this(new BuildTriggerCause(), validationEnabled);
  }
  public BuildTriggerCauseBuilder(io.fabric8.openshift.api.model.BuildTriggerCauseFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildTriggerCauseBuilder(io.fabric8.openshift.api.model.BuildTriggerCauseFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BuildTriggerCause(), validationEnabled);
  }
  public BuildTriggerCauseBuilder(io.fabric8.openshift.api.model.BuildTriggerCauseFluent<?> fluent,io.fabric8.openshift.api.model.BuildTriggerCause instance) {
    this(fluent, instance, false);
  }
  public BuildTriggerCauseBuilder(io.fabric8.openshift.api.model.BuildTriggerCauseFluent<?> fluent,io.fabric8.openshift.api.model.BuildTriggerCause instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBitbucketWebHook(instance.getBitbucketWebHook()); 
    fluent.withGenericWebHook(instance.getGenericWebHook()); 
    fluent.withGithubWebHook(instance.getGithubWebHook()); 
    fluent.withGitlabWebHook(instance.getGitlabWebHook()); 
    fluent.withImageChangeBuild(instance.getImageChangeBuild()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BuildTriggerCauseBuilder(io.fabric8.openshift.api.model.BuildTriggerCause instance) {
    this(instance,false);
  }
  public BuildTriggerCauseBuilder(io.fabric8.openshift.api.model.BuildTriggerCause instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBitbucketWebHook(instance.getBitbucketWebHook()); 
    this.withGenericWebHook(instance.getGenericWebHook()); 
    this.withGithubWebHook(instance.getGithubWebHook()); 
    this.withGitlabWebHook(instance.getGitlabWebHook()); 
    this.withImageChangeBuild(instance.getImageChangeBuild()); 
    this.withMessage(instance.getMessage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.BuildTriggerCauseFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.BuildTriggerCause build() {
    BuildTriggerCause buildable = new BuildTriggerCause(fluent.getBitbucketWebHook(),fluent.getGenericWebHook(),fluent.getGithubWebHook(),fluent.getGitlabWebHook(),fluent.getImageChangeBuild(),fluent.getMessage());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildTriggerCauseBuilder that = (BuildTriggerCauseBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.2.0-sources.jar: io/fabric8/openshift/api/model/BuildTriggerCauseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BuildTriggerCauseBuilder extends BuildTriggerCauseFluentImpl<BuildTriggerCauseBuilder> implements VisitableBuilder<BuildTriggerCause,BuildTriggerCauseBuilder>{
  public BuildTriggerCauseBuilder() {
    this(false);
  }
  public BuildTriggerCauseBuilder(Boolean validationEnabled) {
    this(new BuildTriggerCause(), validationEnabled);
  }
  public BuildTriggerCauseBuilder(BuildTriggerCauseFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildTriggerCauseBuilder(BuildTriggerCauseFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BuildTriggerCause(), validationEnabled);
  }
  public BuildTriggerCauseBuilder(BuildTriggerCauseFluent<?> fluent,BuildTriggerCause instance) {
    this(fluent, instance, false);
  }
  public BuildTriggerCauseBuilder(BuildTriggerCauseFluent<?> fluent,BuildTriggerCause instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBitbucketWebHook(instance.getBitbucketWebHook()); 
    fluent.withGenericWebHook(instance.getGenericWebHook()); 
    fluent.withGithubWebHook(instance.getGithubWebHook()); 
    fluent.withGitlabWebHook(instance.getGitlabWebHook()); 
    fluent.withImageChangeBuild(instance.getImageChangeBuild()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BuildTriggerCauseBuilder(BuildTriggerCause instance) {
    this(instance,false);
  }
  public BuildTriggerCauseBuilder(BuildTriggerCause instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withBitbucketWebHook(instance.getBitbucketWebHook()); 
    this.withGenericWebHook(instance.getGenericWebHook()); 
    this.withGithubWebHook(instance.getGithubWebHook()); 
    this.withGitlabWebHook(instance.getGitlabWebHook()); 
    this.withImageChangeBuild(instance.getImageChangeBuild()); 
    this.withMessage(instance.getMessage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  BuildTriggerCauseFluent<?> fluent;
  Boolean validationEnabled;
  public BuildTriggerCause build() {
    BuildTriggerCause buildable = new BuildTriggerCause(fluent.getBitbucketWebHook(),fluent.getGenericWebHook(),fluent.getGithubWebHook(),fluent.getGitlabWebHook(),fluent.getImageChangeBuild(),fluent.getMessage());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
